import better_exceptions
better_exceptions.hook()

foo = 52


def shallow(a, b):
    deep(a + b)


def deep(val):
    global foo
    assert val > 10 and foo == 60


bar = foo - 50
shallow(bar, 15)
shallow(bar, 2)



# -*- coding:utf-8 -*-

import better_exceptions
better_exceptions.hook()

def div(x, y):
    x / y

def cause(x, y):
    try:
        div(x, y)
    except Exception:
        raise ValueError("Division error")

def context(x, y):
    try:
        cause(x, y)
    except Exception as e:
        raise ValueError("Cause error") from e

context(1, 0)



import code

class QuietConsole(code.InteractiveConsole, object):
    def __init__(self):
        super(self.__class__, self).__init__()

    def interact(self):
        return super(self.__class__, self).interact('')


if __name__ == '__main__':
    QuietConsole().interact()



import better_exceptions
import logging

better_exceptions.hook()
logging.basicConfig()

logger = logging.getLogger(__name__)

logging.raiseExceptions = True

qux = 15

def foo(cb):
    qix = 20
    try:
        cb()
    except:
        logger.exception('callback failed')


def bar1():
    baz = 80.5
    logger.info('Hello')


def bar2():
    baz = 890.50
    logger.info('Hello', exc_info=True)


def bar3():
    baz = 600.524
    raise Exception('this is a test exception')


def bar4():
    baz = 52
    assert baz == 90


FNS = [
    bar1,
    bar2,
    bar3,
    bar4
]


for fn in FNS:
    foo(fn)



import io
import sys
import unittest
import better_exceptions

STREAM = io.BytesIO() if sys.version_info[0] == 2 else io.StringIO()


def add(a, b):
    return a + b


class MyTestCase(unittest.TestCase):
    def test_add(self):
        self.assertEqual(add(1, "2"), 3)


class SilentTestRunner(unittest.TextTestRunner):
    """
    The default TextTestRunner will print something like 'Ran 1 test in 0.017s'
    into stderr, and values are different from different tests. To ensure that
    CI script can compare between the outputs, those information must be muted.
    """

    def __init__(self, stream=STREAM, *args, **kwargs):
        super(SilentTestRunner, self).__init__(STREAM, *args, **kwargs)


def print_test_error():
    test = unittest.main(exit=False, testRunner=SilentTestRunner)
    error = test.result.errors[0][1]
    # unittest.TestResult.errors is "A list containing 2-tuples of TestCase
    # instances and strings holding formatted tracebacks. Each tuple represents
    # a test which raised an unexpected exception."
    assert isinstance(error, str)
    lines = error.splitlines()
    print("\n".join(lines[4:]))  # remove '/removed/for/test/purposes.py'


def main():
    print_test_error()

    def patch(self, err, test):
        lines = better_exceptions.format_exception(*err)
        if sys.version_info[0] == 2:
            return u"".join(lines).encode("utf-8")
        else:
            return u"".join(lines)

    unittest.result.TestResult._exc_info_to_string = patch

    print_test_error()


if __name__ == "__main__":
    main()



import re
from itertools import chain
from os.path import basename
from os.path import dirname
from os.path import join
from os.path import splitext
from distutils.core import setup
from distutils.command.build import build
from setuptools.command.develop import develop
from setuptools.command.easy_install import easy_install
from setuptools.command.install_lib import install_lib


class BuildWithPTH(build):
    def run(self):
        build.run(self)
        path = join(dirname(__file__), 'better_exceptions_hook.pth')
        dest = join(self.build_lib, basename(path))
        self.copy_file(path, dest)


class EasyInstallWithPTH(easy_install):
    def run(self):
        easy_install.run(self)
        path = join(dirname(__file__), 'better_exceptions_hook.pth')
        dest = join(self.install_dir, basename(path))
        self.copy_file(path, dest)


class InstallLibWithPTH(install_lib):
    def run(self):
        install_lib.run(self)
        path = join(dirname(__file__), 'better_exceptions_hook.pth')
        dest = join(self.install_dir, basename(path))
        self.copy_file(path, dest)
        self.outputs = [dest]

    def get_outputs(self):
        return chain(install_lib.get_outputs(self), self.outputs)


class DevelopWithPTH(develop):
    def run(self):
        develop.run(self)
        path = join(dirname(__file__), 'better_exceptions_hook.pth')
        dest = join(self.install_dir, basename(path))
        self.copy_file(path, dest)


with open('better_exceptions/__init__.py', 'r') as file:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        file.read(), re.MULTILINE).group(1)

setup(
    name = 'better_exceptions',
    packages = ['better_exceptions', 'better_exceptions.integrations'],
    version = version,
    description = 'Pretty and helpful exceptions, automatically',
    author = 'Josh Junon',
    author_email = 'pypi@josh.junon.me',
    url = 'https://github.com/qix-/better-exceptions',
    download_url = 'https://github.com/qix-/better-exceptions/archive/{}.tar.gz'.format(version),
    license = 'MIT',
    keywords = ['pretty', 'better', 'exceptions', 'exception', 'error', 'local', 'debug', 'debugging', 'locals'],
    classifiers = [],
    extras_require = {
        ':sys_platform=="win32"': ['colorama']
    },
    # This all comes from pytest-cov repository:
    # https://github.com/pytest-dev/pytest-cov/blob/cde7c378b6a1971957759f42ac91e2860b41cf89/setup.py
    cmdclass = {
        'build': BuildWithPTH,
        'easy_install': EasyInstallWithPTH,
        'install_lib': InstallLibWithPTH,
        'develop': DevelopWithPTH,
    }
)
